% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/elasticache_operations.R
\name{elasticache_describe_events}
\alias{elasticache_describe_events}
\title{Returns events related to clusters, cache security groups, and cache
parameter groups}
\usage{
elasticache_describe_events(SourceIdentifier, SourceType, StartTime,
  EndTime, Duration, MaxRecords, Marker)
}
\arguments{
\item{SourceIdentifier}{The identifier of the event source for which events are returned. If not
specified, all sources are included in the response.}

\item{SourceType}{The event source to retrieve events for. If no value is specified, all
events are returned.}

\item{StartTime}{The beginning of the time interval to retrieve events for, specified in
ISO 8601 format.

\strong{Example:} 2017-03-30T07:03:49.555Z}

\item{EndTime}{The end of the time interval for which to retrieve events, specified in
ISO 8601 format.

\strong{Example:} 2017-03-30T07:03:49.555Z}

\item{Duration}{The number of minutes worth of events to retrieve.}

\item{MaxRecords}{The maximum number of records to include in the response. If more
records exist than the specified \code{MaxRecords} value, a marker is
included in the response so that the remaining results can be retrieved.

Default: 100

Constraints: minimum 20; maximum 100.}

\item{Marker}{An optional marker returned from a prior request. Use this marker for
pagination of results from this operation. If this parameter is
specified, the response includes only records beyond the marker, up to
the value specified by \code{MaxRecords}.}
}
\value{
A list with the following syntax:\preformatted{list(
  Marker = "string",
  Events = list(
    list(
      SourceIdentifier = "string",
      SourceType = "cache-cluster"|"cache-parameter-group"|"cache-security-group"|"cache-subnet-group"|"replication-group"|"user"|"user-group",
      Message = "string",
      Date = as.POSIXct(
        "2015-01-01"
      )
    )
  )
)
}
}
\description{
Returns events related to clusters, cache security groups, and cache
parameter groups. You can obtain events specific to a particular
cluster, cache security group, or cache parameter group by providing the
name as a parameter.

By default, only the events occurring within the last hour are returned;
however, you can retrieve up to 14 days' worth of events if necessary.
}
\section{Request syntax}{
\preformatted{svc$describe_events(
  SourceIdentifier = "string",
  SourceType = "cache-cluster"|"cache-parameter-group"|"cache-security-group"|"cache-subnet-group"|"replication-group"|"user"|"user-group",
  StartTime = as.POSIXct(
    "2015-01-01"
  ),
  EndTime = as.POSIXct(
    "2015-01-01"
  ),
  Duration = 123,
  MaxRecords = 123,
  Marker = "string"
)
}
}

\keyword{internal}
